==> migrate_wizard-1.0.1-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWGenericText.php <==
<?php

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'generic_text' field type.
 *
 * @FieldType(
 *   id = "generic_text",
 * )
 */
class FieldTypeMWGenericText extends FieldTypeMWBase {

  public static function getMigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $field_collection = NULL) {


    $method = 'process';
    $sufix = '_value';
    if ($data_field['destiny'] == 'title' || $data_field['destiny'] == 'name') {
      $method = 'row';
      $sufix = '';
    }
    if ($data_field['type'] == 'email') {
      $sufix = '_email';
    }

    if ($data_field['destiny'] == 'name' && $wildcard_yml_config["destination"]["plugin"] == 'entity:taxonomy_term') {
      $wildcard_yml_config["process"]["name"][0]["source"] = $origin_field;
    }
    $array_config[$data_field['destiny']][] = [
      'plugin' => 'skip_on_empty',
      'source' => $origin_field . $sufix,
      'method' => $method,
    ];
    $array_config[$data_field['destiny']][] = [
      'plugin' => 'explode',
      'method' => 'process',
      'delimiter' => '||',
    ];
    if(!$field_collection){
      $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);
    }else{
      foreach($array_config[$data_field['destiny']] as $value){
        $wildcard_yml_config['process'] = parent::insertBeforeKey($wildcard_yml_config['process'], $field_collection, $data_field['destiny'], $value);
      }
    }


//    $wildcard_yml_config['process'][$data_field['destiny']][] = [
//      'plugin' => 'skip_on_empty',
//      'source' => $origin_field . $sufix,
//      'method' => $method,
//    ];
//    $wildcard_yml_config['process'][$data_field['destiny']][] = [
//      'plugin' => 'explode',
//      'method' => 'process',
//      'delimiter' => '||',
//    ];
  }

  public function addQueryByType($alias, $table, $data_field, $wildcard, $translation, $field_collection = NULL) {

    if(($wildcard->getDestinyType() == 'node' && $data_field["destiny"] != 'title') ||
      (($wildcard->getDestinyType() == 'taxonomy_term' && $data_field["destiny"] != 'name')) ||
      (($wildcard->getDestinyType() == 'user' && $data_field["destiny"] != 'name'))){
      $base_field = str_replace('field_data_', '', $table);
      $sufix = '_value';
      if ($data_field['destiny'] == 'title' || $data_field['destiny'] == 'name') {
        $sufix = '';
      }
      if ($data_field['type'] == 'email') {
        $sufix = '_email';
      }
      if($field_collection == NULL){
        $wildcard->query->leftJoin($table, $alias, "{$wildcard->getValue('leftJoinTable')} = $alias.entity_id AND $alias.entity_type = '{$wildcard->getValue('entityType')}' AND $alias.bundle = '{$wildcard->getValue('bundle')}'");
      }else{
        $wildcard->query->leftJoin($table, $alias, "{$field_collection['left_join_table']} = $alias.entity_id AND $alias.entity_type = 'field_collection_item' AND $alias.bundle = '{$field_collection['bundle']}'");
      }
      $wildcard->query->addExpression("GROUP_CONCAT(DISTINCT CONCAT (COALESCE($alias.{$base_field}{$sufix}, '')) ORDER BY $alias.delta ASC SEPARATOR '||')", $base_field.$sufix , []);
    }
  }

}

==> migrate_wizard-1.0.8-alpha1.tar.gz: migrate_wizard/src/Plugin/FieldTypeMW/FieldTypeMWGenericText.php <==
<?php

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'generic_text' field type.
 *
 * @FieldType(
 *   id = "generic_text",
 * )
 */
class FieldTypeMWGenericText extends FieldTypeMWBase {

  public static function getMigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $field_collection = NULL) {


    $method = 'process';
    $sufix = '_value';
    if ($data_field['destiny'] == 'title' || $data_field['destiny'] == 'name') {
      $method = 'row';
      $sufix = '';
    }
    if ($data_field['type'] == 'email') {
      $sufix = '_email';
    }

    $sourceName = $origin_field;
    if ($data_field['destiny'] == 'name' &&
        $wildcard_yml_config["destination"]["plugin"] == 'entity:taxonomy_term' &&
        isset($wildcard_yml_config["source"]["translations"]) &&
        $wildcard_yml_config["source"]["translations"] &&
        isset($wildcard_yml_config["process"]["tid"]["source"]) &&
        $wildcard_yml_config["process"]["tid"]["source"] == 'tid') {
        $sourceName = 'translation';
    }
    $array_config[$data_field['destiny']][] = [
      'plugin' => 'skip_on_empty',
      'source' => $sourceName . $sufix,
      'method' => $method,
    ];
    $array_config[$data_field['destiny']][] = [
      'plugin' => 'explode',
      'method' => 'process',
      'delimiter' => '||',
    ];
    if(!$field_collection){
      $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);
    }else{
      foreach($array_config[$data_field['destiny']] as $value){
        $wildcard_yml_config['process'] = parent::insertBeforeKey($wildcard_yml_config['process'], $field_collection, $data_field['destiny'], $value);
      }
    }


//    $wildcard_yml_config['process'][$data_field['destiny']][] = [
//      'plugin' => 'skip_on_empty',
//      'source' => $origin_field . $sufix,
//      'method' => $method,
//    ];
//    $wildcard_yml_config['process'][$data_field['destiny']][] = [
//      'plugin' => 'explode',
//      'method' => 'process',
//      'delimiter' => '||',
//    ];
  }

  public function addQueryByType($alias, $table, $data_field, $wildcard, $translation, $field_collection = NULL) {

    if(($wildcard->getDestinyType() == 'node' && $data_field["destiny"] != 'title') ||
      (($wildcard->getDestinyType() == 'taxonomy_term' && $data_field["destiny"] != 'name')) ||
      (($wildcard->getDestinyType() == 'user' && $data_field["destiny"] != 'name'))){
      $base_field = str_replace('field_data_', '', $table);
      $sufix = '_value';
      if ($data_field['destiny'] == 'title' || $data_field['destiny'] == 'name') {
        $sufix = '';
      }
      if ($data_field['type'] == 'email') {
        $sufix = '_email';
      }
      if($field_collection == NULL){
        $wildcard->query->leftJoin($table, $alias, "{$wildcard->getValue('leftJoinTable')} = $alias.entity_id AND $alias.entity_type = '{$wildcard->getValue('entityType')}' AND $alias.bundle = '{$wildcard->getValue('bundle')}'");
      }else{
        $wildcard->query->leftJoin($table, $alias, "{$field_collection['left_join_table']} = $alias.entity_id AND $alias.entity_type = 'field_collection_item' AND $alias.bundle = '{$field_collection['bundle']}'");
      }
      $wildcard->query->addExpression("GROUP_CONCAT(DISTINCT CONCAT (COALESCE($alias.{$base_field}{$sufix}, '')) ORDER BY $alias.delta ASC SEPARATOR '||')", $base_field.$sufix , []);
    }
  }

}
